import '../styles/index.scss';

import React, { Component } from 'react';
import { render } from "react-dom";

import Gallery from "react-photo-gallery";
import { Modal, ModalGateway } from "react-images";
import ImageGallery from "react-image-gallery";


const addr_prefix = "" //"http://localhost:8000"


class Main extends Component {
    constructor(props) {
        super(props);
        this.state = {
            text: "",
            status: "",
            faq: false,
            results: [],
            page: window.location.hash,
            photos: [],
            photoIsOpen: false,
            currentImage: 0,
        };
        fetch(addr_prefix + "/api/results").then(resp => resp.json()).then(json => {
            this.setState({results: json})
        })
        fetch(addr_prefix + "/api/photos").then(resp => resp.json()).then(json => {
            this.setState({photos: json})
        })
        if(window.location.search){
            let searchParams = new URLSearchParams(window.location.search);
            for(const [key, value] of searchParams){
                if (key == "refId"){
                    fetch(addr_prefix + "/api/payment_state?refId=" + value).then(resp => resp.json()).then(json =>{
                        this.setState({status: json.status, text: json.reason})
                    })
                }
            }
        }
        window.addEventListener("hashchange", (e) => {this.onHashChange(e)})
    }
    closePhoto = () => {
        this.setState(state => ({ photoIsOpen: false }))
    }
    openPhoto = (event, {index}) => {
        this.setState({
            currentImage: index,
            photoIsOpen: true,
        })
    }
    onHashChange(event){
        this.setState({page: window.location.hash})
    }
    onSubmit(event){
        event.preventDefault();
        let form = document.getElementById("form");
        let formData = new FormData(form);
        fetch(addr_prefix + "/api/register", {
            method:"POST",
            body: formData,
        }).then(resp => resp.json()).then(json => {
            if(json.reason){
                this.setState({
                    text: json.reason,
                    status: "failed",
                })
            } else {
                this.setState({
                    text: json.success,
                    status: "success",
                })
                window.open(json.redirect ,"_self")
            }
        });
    }
    togglefaq(){
        this.setState({faq: !this.state.faq});
    }
    renderCloseButton(){
        return <button class="image-gallery-close image-gallery-icon" onClick={(e) => {this.closePhoto()}}>
            <svg xmlns="http://www.w3.org/2000/svg" width="92" height="92" id="cross"><path fill="white" d="M70.7 64.3c1.8 1.8 1.8 4.6 0 6.4-.9.9-2 1.3-3.2 1.3-1.2 0-2.3-.4-3.2-1.3L46 52.4 27.7 70.7c-.9.9-2 1.3-3.2 1.3s-2.3-.4-3.2-1.3c-1.8-1.8-1.8-4.6 0-6.4L39.6 46 21.3 27.7c-1.8-1.8-1.8-4.6 0-6.4 1.8-1.8 4.6-1.8 6.4 0L46 39.6l18.3-18.3c1.8-1.8 4.6-1.8 6.4 0 1.8 1.8 1.8 4.6 0 6.4L52.4 46l18.3 18.3z"></path></svg>
        </button>
    }
    render(){
        let photos_gallery = [];
        let photos_carousel = []
        for (const photo of this.state.photos){
            photos_gallery.push({
                src: photo.thumbnail,
                width: photo.original_width,
                height: photo.original_height,
            })
            photos_carousel.push({
                original: photo.original
            })
        };
        return (
<div>
    <ModalGateway>
        {this.state.photoIsOpen &&
        <Modal onClose={this.closePhoto}>
            <ImageGallery
                items={photos_carousel}
                lazyLoad={true}
                showPlayButton={false}
                startIndex={this.state.currentImage}
                showThumbnails={false}
                renderCustomControls={this.renderCloseButton.bind(this)}
            />
        </Modal>
        }
    </ModalGateway>
    <nav class="navbar navbar-expand-lg bg-body-tertiary">
        <div class="container">
            <ul class="navbar-nav mb-0">
                <li class="nav-item">
                    <a class="nav-link" aria-current="page" href="#">Domů</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#gallery">Galerie</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#payment">Platba</a>
                </li>
            </ul>
        </div>
    </nav>
    {this.state.page == "#payment" &&
    <div class="container text">
        Platební bránu poskytuje firma <a href="https://www.comgate.cz/cz/platebni-brana">Comgate, a.s</a>. Platit je možné pomocí <a href="https://help.comgate.cz/v1/docs/cs/platby-kartou">platební karty</a> nebo <a href="https://help.comgate.cz/docs/bankovni-prevody">bankovním převodem</a>. Podrobnosti a přesný postup platby včetně animací najdete v odkazech.<br />
        Kontakt na Comgate, a.s.<br />
        Gočárova třída 1754 / 48b, Hradec Králové<br />
        E-mail: platby-podpora@comgate.cz<br />
        Tel: +420 228 224 267<br />
    </div>
    }
    {this.state.page == "#gallery" &&
    <div class="container">
        <Gallery photos={photos_gallery} onClick={this.openPhoto}/>
    </div>
    }
    {this.state.page == "" &&
    <div>
        {this.state.status == "success" &&
        <div class="absolute container-fluid alert alert-success">
            {this.state.text}
        </div>}
        {this.state.status == "failed" &&
        <div class="absolute container-fluid alert alert-danger">
            {this.state.text}
        </div>}
        {this.state.faq &&
            <div class="shadow"></div>}
        {this.state.faq &&
            <div class="faq" onClick={(e) => this.togglefaq()}>
                <div class="container" onClick={(e) => e.stopPropagation()}>
                    <button type="button" class="btn-close" aria-label="Close" onClick={(e) => this.togglefaq()}></button>
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Proč je cena startovného taková, jaká je?</h5>
                            <p class="card-text">Vetšinu ceny dělá alkohol a nápoje, které se během závodu konzumují. Dostanete přívěšek s panákem, který Vám zůstává a pokud závod doběhnete, dostanete památeční medaili. Zbytek startovného tvoří výherní ceny, dále náklady spojené s organizací závodu. Výroba překážek, časovačů na čekárnách, náramky pro závodníký, tisk plakátů a jejich propagace, atd. Cenu jsme se snažili nastavit co nejnižší, zároveň takovou, abychom byli schopní Alkátor Race uskutečnit.</p>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">K čemu slouží Tokken?</h5>
                            <p class="card-text">V kontextu Alkátor Race by se to dalo spíše nazvat kontrolním bodem. Závodník doběhne na určité místo, kde tokken sebere a následně ho zanese na další stanoviště, kde ho předáte kontrolorovi. Tím dáte najevo, že jste běžel trasu správě. Je to pojistka, aby jsi byl podctivý Alkátor a nešvindloval!</p>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Jak funguje Quíz?</h5>
                            <p class="card-text">Jedná se o překážku, kde na daném místě vylosujete otázku a běžíte k dalšímu stanovišti ke kontrolorovi. Mezi tím si můžete promyslet jednu z ze tří odpovědí (formát A,B,C). Špatná odpopvěď znamená panáčka. Navíc to má obdobnou funkci, jako Tokken.</p>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Jak funguje Ruleta?</h5>
                            <p class="card-text">Na stanovišti na Vás budou čekat panáčky. Obsah může být cokoliv alkoholického i nealkoholického, od dobrot po blééé. Nejlepší na tom je, že podle čichu a barvy nemáte šanci poznat, o co se jedná. Jelikož panáčky jsou uzavřené a dobarvené potravinářským barvivem.</p>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Musím v Alkátor race utíkat nebo se jinak fyzicky namáhat?</h5>
                            <p class="card-text">Strategii závodu si určím sám s pomocí mého osobního trenéra. Tudíž se zaměřím hlavně na alkohol a abych dorazil do cíle jako hrdina a ostřílený alko-veterán.</p>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Kolik spoluúčastníků mám očekávat?</h5>
                            <p class="card-text">Zatím je kapacita závodu 50 účastníků.</p>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            <h5 class="card-title">Co když jsem zde svůj dotaz nenašel?</h5>
                            <p class="card-text">Tak neváhej a kontaktuj nás na sociálních sítích nebo emailu, rádi pomůžeme.</p>
                        </div>
                    </div>
                </div>
            </div>
        }
        <div class="container">
            <img class="logo" src="/public/logo.svg"></img>
        </div>
        <div class="container info text-center">
            <div class="row">
                <h1 class="col val">
                    <b>KDY?</b>
                    <br />
                    5.10.2024
                </h1>
                <h1 class="col val">
                    <b>V KOLIK?</b>
                    <br />
                    10:00
                </h1>
                <h1 class="col val">
                    <b>KDE?</b>
                    <br />
                    Studené
                </h1>
                <h1 class="col val">
                    <b>CENA</b>
                    <br />
                    Do 20.9. 690 kč*
                </h1>
            </div>
        </div>
        <div class="container">
            <div class="row">
                <div class="text col-xl-6">
                    <p>Vítej člověče! Momentálně se nacházíš na oficiální stránce závodu ALKÁTOR RACE.</p>

                    <p>A co že jsme si to zase vymysleli!? </p>

                    <p>Jedná se o překážkový závod u nás v Orlických horách. Celkem máme připravených kolem 30 překážek a trať měří kolem 4 km. V závodě tě čeká pěkných pár panáků, kdy počty se pohybují od 3-15 kousků podle toho jak dobře si na překážkách povedeš. Dále máme v závodě překážku zvanou "Čekárna" na které si deset minut odpočneš a dáš si oddychové pivínko na nejkrásnějších místech v okolí Studené. Čekárny tě v závodě čekají hned čtyři. </p>

                    <p>Pokud v průběhu závodu dostaneš pocit, že je to nad tvé síly, vždy budeš mít tu možnost přestoupit do kategorie Alkátor Race LIGHT, kde sice ztratíš možnost stanout na stupních vítězů, ale budeš moci plně regulovat svou obtížnost závodu.
                    Takže když budeš mít špatný den, nikdo tě nebude do ničeho nutit a ty si užiješ atmosféru akce na plné pecky.</p>

                    <p>Našim smělým alkátorkám nebudeme nic extra zjednodušovat, pouze na čekárnách budou konzumovat poloviční dávky piva(pokud budou chtít).
                    Pravděpodobně bude otevřena i kategorie NEAlkátor Race - zaměřena na řidiče, abstinenty a nezletilé.</p>

                    <p>Pro alkátory/rky na stupních vítězů čekají úžasné ceny.</p>

                    <p>Start závodu je v 10:00, ale check-in se zahájením akce je již od 8:30.</p>

                    <p>* S blížícím se závodem bude 21.9 zvednuta cena na 790 kč.</p>

                    <p>Rozhodně se podívej na FAQ sekci, zde na stránce, kde najdeš důležité informace týkající se závodu ALKÁTOR RACE.</p>
                    <p>Sportem ku chlastu!</p>
                </div>
                <div class="col-xl-6">
                    <h1 class="text"    >Výsledky 1. ročníku</h1>
                    {this.state.results &&
                        <table class="table results">
                            <thead>
                                <th>Umístění</th>
                                <th>Čas</th>
                                <th>Kategorie</th>
                                <th>Startovní číslo</th>
                            </thead>
                            <tbody>
                                {this.state.results.map(user =>
                                    <tr>
                                        <th>{user.order}</th>
                                        <td>{user.duration}</td>
                                        <td>{user.alkator_category}</td>
                                        <td>{user.starting_number}</td>
                                    </tr>
                                )}
                            </tbody>
                        </table>
                    }
                    {/*
                    <img src="/public/trasa.png" style={{'width': '100%', 'height': 'auto'}}/>
                    */}
                    <iframe width="100%" height="500px" src="https://www.youtube.com/embed/INYakiBnVNk?si=Nx9QtADyt_4XI5BC" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen="true" />
                </div>
            </div>
        </div>
        <div class="container text text-center">
            <h2>Stále nevíš, jestli se zúčastníš? Přečti si náš <button type="button" class="btn btn-warning" onClick={(e) => this.togglefaq()}>FAQ</button></h2>
        </div>
        <form id="form" class="container" onSubmit={(e) => this.onSubmit(e)}>
            <h1>Registrace</h1>
            <div class="mb-3">
                <label for="first_name" class="form-label">Jméno</label>
                <input type="text" class="form-control" id="first_name" name="first_name" />
            </div>
            <div class="mb-3">
                <label for="last_name" class="form-label">Přijmení</label>
                <input type="text" class="form-control" id="last_name" name="last_name" />
            </div>
            <div class="mb-3">
                <label for="email" class="form-label">Emailová adresa</label>
                <input type="email" class="form-control" id="email" name="email" />
            </div>
            <div class="mb-3">
                <label for="date_of_birth" class="form-label">Datum narození</label>
                <input type="date" class="form-control" id="date_of_birth" name="date_of_birth" max={new Date().toJSON().slice(0, 10)} />
            </div>
            <div class="mb-3">
                <label for="phone" class="form-label">Telefonní číslo</label>
                <input type="text" class="form-control" id="phone" name="phone" />
            </div>
            <div class="mb-3">
                <label for="address" class="form-label">Adresa (kvůli fakturaci)</label>
                <input type="text" class="form-control" id="address" name="address" />
            </div>
            <div class="mb-3 form-check">
                <input type="checkbox" class="form-check-input" id="agreement" name="agreement" />
                <label class="form-check-label" for="agreement">Souhlas se <a href="/public/ochrana_osobnich_udaju.pdf">zpracováním osobních údajů</a>, <a href="/public/reverz.pdf">podmínkami závodu</a> a <a href="/public/obchodni_podminky_alkator.pdf">obchodníma podmínkami závodu</a>.</label>
            </div>
            <button type="submit" class="btn btn-primary">Odeslat a zaplatit</button>
        </form>
        <div class="container text-center social">
            <div class="row">
                <a class="col-lg-3" style={{"color": "black"}} href="mailto:info@alkator.cz"><b>info@alkator.cz</b></a>
                <a class="col-lg-3" href="https://www.facebook.com/AlkatorRace"><img height="40px" src="/public/fb_logo.svg" /></a>
                <a class="col-lg-3" href="https://www.youtube.com/@AlkatorRace"><img height="40px" src="/public/youtube_logo.svg"/></a>
                <a class="col-lg-3" href="https://www.instagram.com/alkator_race/"><img height="40px" src="/public/instagram_logo.svg" /></a>
            </div>
        </div>
        <div class="container video">
            <iframe width="100%" height="800px" src="https://www.youtube.com/embed/v3r2IAPdFFQ?si=kkh2_BBJXw56gVaP" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen="true"></iframe>
        </div>
    </div>
    }
    <div class="container text">
        <a href="/public/reverz.pdf">Reverz</a><br />
        <a href="/public/ochrana_osobnich_udaju.pdf">Ochrana osobních údajů</a><br />
        <a href="/public/obchodni_podminky_alkator.pdf">Obchodní podmínky závodu alkátor</a><br />
        Název společnosti: Zhoor s.r.o.<br />
        IČ: 212 44 863<br />
        DIČ: Nejsme plátci DPH.<br />
        sídlo: Červenovodská 548, Králíky, 561 69<br />
        Číslo účtu: 131-2219860207/0100<br />
        E-mail: info@alkator.cz<br />
        Tel: +420 728 018 088<br />
        <img src="/public/footer.png" style={{"width":"100%","height":"auto"}} />
    </div>
</div>
        );
    }
}

const root = document.getElementById("root");
render(<Main />, root);